@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2009-2020  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2009-2025  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,7 +30,6 @@
 
 from io import StringIO
 from tokenize import generate_tokens
-from typing import Tuple, Dict, List
 
 from relational.relation import Relation
 from relational import parser
@@ -54,7 +53,7 @@ def find_duplicates(node, dups=None):
     dups[str(node)] = node
 
 
-def duplicated_select(n: parser.Node) -> Tuple[parser.Node, int]:
+def duplicated_select(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function locates and deletes things like
     σ a ( σ a(C)) and the ones like σ a ( σ b(C))
     replacing the 1st one with a single select and
@@ -80,7 +79,7 @@ def duplicated_select(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, changes
 
 
-def futile_union_intersection_subtraction(n: parser.Node) -> Tuple[parser.Node, int]:
+def futile_union_intersection_subtraction(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function locates things like r ∪ r, and replaces them with r.
     R ∪ R  --> R
     R ∩ R --> R
@@ -137,7 +136,7 @@ def futile_union_intersection_subtraction(n: parser.Node) -> Tuple[parser.Node,
     return n, 0
 
 
-def down_to_unions_subtractions_intersections(n: parser.Node) -> Tuple[parser.Node, int]:
+def down_to_unions_subtractions_intersections(n: parser.Node) -> tuple[parser.Node, int]:
     '''This funcion locates things like σ i==2 (c ∪ d), where the union
     can be a subtraction and an intersection and replaces them with
     σ i==2 (c) ∪ σ i==2(d).
@@ -153,7 +152,7 @@ def down_to_unions_subtractions_intersections(n: parser.Node) -> Tuple[parser.No
     return n, 0
 
 
-def duplicated_projection(n: parser.Node) -> Tuple[parser.Node, int]:
+def duplicated_projection(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function locates thing like π i ( π j (R)) and replaces
     them with π i (R)'''
 
@@ -165,7 +164,7 @@ def duplicated_projection(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, 0
 
 
-def selection_inside_projection(n: parser.Node) -> Tuple[parser.Node, int]:
+def selection_inside_projection(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function locates things like  σ j (π k(R)) and
     converts them into π k(σ j (R))'''
     if isinstance(n, Unary) and n.name == SELECTION and isinstance(n.child, Unary) and n.child.name == PROJECTION:
@@ -179,7 +178,7 @@ def selection_inside_projection(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, 0
 
 
-def swap_union_renames(n: parser.Node) -> Tuple[parser.Node, int]:
+def swap_union_renames(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function locates things like
     ρ a➡b(R) ∪ ρ a➡b(Q)
     and replaces them with
@@ -199,7 +198,7 @@ def swap_union_renames(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, 0
 
 
-def futile_renames(n: parser.Node) -> Tuple[parser.Node, int]:
+def futile_renames(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function purges renames like
     ρ id->id,a->q (A)
     into
@@ -223,7 +222,7 @@ def futile_renames(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, 0
 
 
-def subsequent_renames(n: parser.Node) -> Tuple[parser.Node, int]:
+def subsequent_renames(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function removes redundant subsequent renames joining them into one
     ρ .. ρ .. (A)
     into
@@ -267,7 +266,7 @@ class LevelString(str):
     level = 0
 
 
-def tokenize_select(expression: str) -> List[LevelString]:
+def tokenize_select(expression: str) -> list[LevelString]:
     '''This function returns the list of tokens present in a
     selection. The expression can contain parenthesis.
     It will use a subclass of str with the attribute level, which
@@ -302,7 +301,7 @@ def tokenize_select(expression: str) -> List[LevelString]:
     return r
 
 
-def swap_rename_projection(n: parser.Node) -> Tuple[parser.Node, int]:
+def swap_rename_projection(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function locates things like
     π k(ρ j(R))
     and replaces them with
@@ -341,7 +340,7 @@ def swap_rename_projection(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, 0
 
 
-def swap_rename_select(n: parser.Node) -> Tuple[parser.Node, int]:
+def swap_rename_select(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function locates things like
     σ k(ρ j(R))
     and replaces them with
@@ -372,7 +371,7 @@ def swap_rename_select(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, 0
 
 
-def select_union_intersect_subtract(n: parser.Node) -> Tuple[parser.Node, int]:
+def select_union_intersect_subtract(n: parser.Node) -> tuple[parser.Node, int]:
     '''This function locates things like
     σ i(a) ∪ σ q(a)
     and replaces them with
@@ -408,7 +407,7 @@ def select_union_intersect_subtract(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, 0
 
 
-def union_and_product(n: parser.Node) -> Tuple[parser.Node, int]:
+def union_and_product(n: parser.Node) -> tuple[parser.Node, int]:
     '''
     A * B ∪ A * C = A * (B ∪ C)
     Same thing with inner join
@@ -433,7 +432,7 @@ def union_and_product(n: parser.Node) -> Tuple[parser.Node, int]:
     return n, 0
 
 
-def projection_and_union(n: parser.Node, rels: Dict[str, Relation]) -> Tuple[parser.Node, int]:
+def projection_and_union(n: parser.Node, rels: dict[str, Relation]) -> tuple[parser.Node, int]:
     '''
     Turns
         π a,b,c(A) ∪ π a,b,c(B)
@@ -456,7 +455,7 @@ def projection_and_union(n: parser.Node, rels: Dict[str, Relation]) -> Tuple[par
     return n, 0
 
 
-def selection_and_product(n: parser.Node, rels: Dict[str, Relation]) -> Tuple[parser.Node, int]:
+def selection_and_product(n: parser.Node, rels: dict[str, Relation]) -> tuple[parser.Node, int]:
     '''This function locates things like σ k (R*Q) and converts them into
     σ l (σ j (R) * σ i (Q)). Where j contains only attributes belonging to R,
     i contains attributes belonging to Q and l contains attributes belonging to both'''
@@ -468,8 +467,8 @@ def selection_and_product(n: parser.Node, rels: Dict[str, Relation]) -> Tuple[pa
         r_attr = n.child.right.result_format(rels)
 
         tokens = tokenize_select(n.prop)
-        groups: List[List[LevelString]] = []
-        temp: List[LevelString] = []
+        groups: list[list[LevelString]] = []
+        temp: list[LevelString] = []
 
         for k in tokens:
             if k == 'and' and k.level == 0:
@@ -536,7 +535,7 @@ def selection_and_product(n: parser.Node, rels: Dict[str, Relation]) -> Tuple[pa
     return n, 0
 
 
-def useless_projection(n: parser.Node, rels: Dict[str, Relation]) -> Tuple[parser.Node, int]:
+def useless_projection(n: parser.Node, rels: dict[str, Relation]) -> tuple[parser.Node, int]:
     '''
     Removes projections that are over all the fields
     '''
