@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2020  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2025  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 # relational query, or it can be a parse tree for a relational expression (ie: class parser.node).
 # The functions will always return a string with the optimized query, but if a parse tree was provided,
 # the parse tree itself will be modified accordingly.
-from typing import Union, Optional, Dict, Any, Tuple
+from typing import Any
 
 from relational.relation import Relation
 from relational import optimizations
@@ -31,13 +31,13 @@ from relational import querysplit
 from relational.maintenance import UserInterface
 
 
-def optimize_program(code: str, rels: Dict[str, Relation]) -> str:
+def optimize_program(code: str, rels: dict[str, Relation]) -> str:
     '''
     Optimize an entire program, composed by multiple expressions
     and assignments.
     '''
     lines = code.split('\n')
-    context: Dict[str, Node] = {}
+    context: dict[str, Node] = {}
 
     last_res = None
     for line in lines:
@@ -59,7 +59,7 @@ def optimize_program(code: str, rels: Dict[str, Relation]) -> str:
     return querysplit.split(node, rels)
 
 
-def _replace_leaves(node: Node, context: Dict[str, Node]) -> None:
+def _replace_leaves(node: Node, context: dict[str, Node]) -> None:
     '''
     If a name appearing in node appears
     also in context, the parse tree is
@@ -80,7 +80,7 @@ def _replace_leaves(node: Node, context: Dict[str, Node]) -> None:
             node.right = context[node.right.name]
 
 
-def optimize_all(expression: Union[str, Node], rels: Dict[str, Relation], specific: bool = True, general: bool = True, debug: Optional[list] = None, tostr: bool = True) -> Union[str, Node]:
+def optimize_all(expression: str | Node, rels: dict[str, Relation], specific: bool = True, general: bool = True, debug: list[str] | None = None, tostr: bool = True) -> str | Node:
     '''This function performs all the available optimizations.
 
     expression : see documentation of this module
@@ -120,7 +120,7 @@ def optimize_all(expression: Union[str, Node], rels: Dict[str, Relation], specif
         return n
 
 
-def _recursive_scan(function, node: Node, rels: Optional[Dict[str, Any]]) -> Tuple[Node, int]:
+def _recursive_scan(function, node: Node, rels: dict[str, Any] | None) -> tuple[Node, int]:
     '''Does a recursive optimization on the tree.
 
     This function will recursively execute the function given
