@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2016-2020  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2016-2025  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,6 @@
 #
 # This module splits a query into a program.
 
-from typing import List, Dict, Tuple
-
 from relational.parser import Node, Binary, Unary, Variable
 
 
@@ -28,8 +26,8 @@ __all__ = ['split']
 
 class Program:
     def __init__(self, rels) -> None:
-        self.queries: List[Tuple[str, Node]] = []
-        self.dictionary: Dict[str, Node] = {} # Key is the query, value is the relation
+        self.queries: list[tuple[str, Node]] = []
+        self.dictionary: dict[str, Node] = {} # Key is the query, value is the relation
         self.vgen = _vargen(rels, 'optm_')
 
     def __str__(self):
