@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2024  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2025  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 from itertools import chain, repeat, product as iproduct
 from collections import deque
-from typing import FrozenSet, Iterable, List, Dict, Tuple, Optional
+from typing import Iterable, Optional
 from dataclasses import dataclass
 from pathlib import Path
 from gettext import gettext as _
@@ -59,10 +59,10 @@ class Relation:
     method.
     '''
     header: 'Header'
-    content: FrozenSet[Tuple[CastValue, ...]]
+    content: frozenset[tuple[CastValue, ...]]
 
     @staticmethod
-    def load_csv(filename: Union[str, Path]) -> 'Relation':
+    def load_csv(filename: str | Path) -> 'Relation':
         '''
         Load a relation object from a csv file.
 
@@ -77,7 +77,7 @@ class Relation:
             return Relation.create_from(header, reader)
 
     @staticmethod
-    def load(filename: Union[str, Path]) -> 'Relation':
+    def load(filename: str | Path) -> 'Relation':
         '''
         Load a relation object from a json file.
         '''
@@ -90,15 +90,15 @@ class Relation:
             for row in loaded['content']:
                 if len(row) != len(header):
                     raise ValueError(_('Line %d contains an incorrect amount of values') % row)
-                t_row: Tuple[Optional[Union[int, float, str, Rdate]], ...] = load(
+                t_row: tuple[int | float | str | Rdate | None, ...] = load(
                     row,
-                    Tuple[Optional[Union[int, float, str, Rdate]], ...],  # type: ignore
+                    tuple[int | float | str | Rdate | None, ...],  # type: ignore
                     basiccast=False
                 )
                 content.append(t_row)
             return Relation(header, frozenset(content))
 
-    def save(self, filename: Union[Path, str]) -> None:
+    def save(self, filename: Path | str) -> None:
         '''
         Saves the relation in a file.
         Will save using the json format
@@ -108,7 +108,7 @@ class Relation:
             from typedload import dump
             jdump(dump(self), fp)
 
-    def save_csv(self, filename: Union[Path, str]) -> None:
+    def save_csv(self, filename: Path | str) -> None:
         '''
         Saves the relation in a file. Will save using the csv
         format as defined in RFC4180.
@@ -125,7 +125,7 @@ class Relation:
             writer.writerows(self.content)
 
     @staticmethod
-    def create_from(header: Iterable[str], content: Iterable[List[str]]) -> 'Relation':
+    def create_from(header: Iterable[str], content: Iterable[list[str]]) -> 'Relation':
         '''
         Iterator for the header, and iterator for the content.
 
@@ -239,7 +239,7 @@ class Relation:
 
         return Relation(header, content)
 
-    def rename(self, params: Dict[str, str]) -> 'Relation':
+    def rename(self, params: dict[str, str]) -> 'Relation':
         '''
         Takes a dictionary.
 
@@ -414,26 +414,23 @@ class Relation:
         return len(self.content)
 
     def __str__(self) -> str:
-        return self.pretty_string(tty=False)
+        return self.pretty_string(color=False)
 
-    def pretty_string(self, tty: bool) -> str:
+    def pretty_string(self, color: bool=True) -> str:
         '''
         Returns a printable string.
 
-        If tty is enabled, it will attempt to add ANSI color codes
+        If color is enabled, it will attempt to add ANSI color codes
         '''
-        c = lambda i, ansi: i
-        if not tty:
-            colorize = c
-        else:
+        colored = lambda i, ansi: i
+        if color:
             from os import isatty
             if isatty(1) and isatty(2):
                 try:
-                    from xtermcolor import colorize  # type: ignore
+                    from termcolor import colored
                 except ModuleNotFoundError:
-                    colorize = c
-            else:
-                colorize = c
+                    pass
+
         m_len = [len(i) + 2 for i in self.header]  # Maximum lenght string
 
         for f in self.content:
@@ -443,18 +440,18 @@ class Relation:
 
         res = ""
         for j, attr in enumerate(self.header):
-            res += colorize(attr.ljust(m_len[j]), ansi=3)
+            res += colored(attr.ljust(m_len[j]), 'yellow')
 
         for r in self.content:
             res += "\n"
             for col, i in enumerate(r):
                 cell = str(i).ljust(m_len[col])
                 if isinstance(i, (int, float)):
-                    cell = colorize(cell, ansi=4)
+                    cell = colored(cell, 'blue')
                 elif i is None:
-                    cell = colorize(cell, ansi=1)
+                    cell = colored(cell, 'red')
                 elif not isinstance(i, str):
-                    cell = colorize(cell, ansi=15)
+                    cell = colored(cell, 'purple')
                 res += cell
 
         return res
@@ -481,7 +478,7 @@ class Header(tuple):
     def __repr__(self):
         return "Header(%s)" % super(Header, self).__repr__()
 
-    def rename(self, params: Dict[str, str]) -> 'Header':
+    def rename(self, params: dict[str, str]) -> 'Header':
         '''Returns a new header, with renamed fields.
 
         params is a dictionary of {old:new} names
@@ -501,15 +498,15 @@ class Header(tuple):
         '''Returns how many attributes this header has in common with a given one'''
         return len(set(self).intersection(set(other)))
 
-    def union(self, other: 'Header') -> Set[str]:
+    def union(self, other: 'Header') -> set[str]:
         '''Returns the union of the sets of attributes with another header.'''
         return set(self).union(set(other))
 
-    def intersection(self, other: 'Header') -> Set[str]:
+    def intersection(self, other: 'Header') -> set[str]:
         '''Returns the set of common attributes with another header.'''
         return set(self).intersection(set(other))
 
-    def getAttributesId(self, param: Iterable[str]) -> List[int]:
+    def getAttributesId(self, param: Iterable[str]) -> list[int]:
         '''Returns a list with numeric index corresponding to field's name'''
         try:
             return [self.index(i) for i in param]
