@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2020  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2025  Salvo "LtWorf" Tomaselli
 #
 # Relation is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,47 +23,11 @@
 import datetime
 import keyword
 import re
-from typing import Union, Set, Any, Callable, Type, Optional
+from typing import Any, Callable, Type
 from dataclasses import dataclass
 from gettext import gettext as _
 
 
-RELATION_NAME_REGEXP = re.compile(r'^[_a-z][_a-z0-9]*$', re.IGNORECASE)
-_date_regexp = re.compile(
-        r'^([0-9]{1,4})(\\|-|/)([0-9]{1,2})(\\|-|/)([0-9]{1,2})$'
-    )
-CastValue = Optional[Union[str, int, float, 'Rdate']]
-
-
-def guess_type(value: str) -> Set[Union[Callable[[Any], Any], Type['Rdate']]]:
-    r: Set[Union[Callable[[Any], Any], Type['Rdate']]] = {str}
-    if _date_regexp.match(value) is not None:
-        r.add(Rdate)
-
-    try:
-        int(value)
-        r.add(int)
-    except ValueError:
-        pass
-
-    try:
-        float(value)
-        r.add(float)
-    except ValueError:
-        pass
-    return r
-
-
-def cast(value: str, guesses: Set) -> CastValue:
-    if int in guesses:
-        return int(value)
-    if Rdate in guesses:
-        return Rdate.create(value)
-    if float in guesses:
-        return float(value)
-    return value
-
-
 @dataclass(frozen=True)
 class Rdate:
     '''Represents a date'''
@@ -107,6 +71,42 @@ class Rdate:
         return self.intdate < other.intdate
 
 
+RELATION_NAME_REGEXP = re.compile(r'^[_a-z][_a-z0-9]*$', re.IGNORECASE)
+_date_regexp = re.compile(
+        r'^([0-9]{1,4})(\\|-|/)([0-9]{1,2})(\\|-|/)([0-9]{1,2})$'
+    )
+CastValue = str | int | float | Rdate | None
+
+
+def guess_type(value: str) -> set[Callable[[Any], Any] | Type['Rdate']]:
+    r: set[Callable[[Any], Any] | Type['Rdate']] = {str}
+    if _date_regexp.match(value) is not None:
+        r.add(Rdate)
+
+    try:
+        int(value)
+        r.add(int)
+    except ValueError:
+        pass
+
+    try:
+        float(value)
+        r.add(float)
+    except ValueError:
+        pass
+    return r
+
+
+def cast(value: str, guesses: set) -> CastValue:
+    if int in guesses:
+        return int(value)
+    if Rdate in guesses:
+        return Rdate.create(value)
+    if float in guesses:
+        return float(value)
+    return value
+
+
 def is_valid_relation_name(name: str) -> bool:
     '''Checks if a name is valid for a relation.
     Returns boolean'''
