@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2016-2024  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2016-2025  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ from PyQt6.QtCore import Qt
 from PyQt6.QtGui import QColor
 from PyQt6.QtGui import QPalette
 from PyQt6.QtGui import QTextCharFormat
+from PyQt6.QtGui import QWheelEvent
 
 
 class Editor(QPlainTextEdit):
@@ -35,7 +36,7 @@ class Editor(QPlainTextEdit):
         self._cursor_moved()
         self.cursorPositionChanged.connect(self._cursor_moved)
 
-    def _cursor_moved(self):
+    def _cursor_moved(self) -> None:
         selections = []
 
         # Current line
@@ -56,16 +57,18 @@ class Editor(QPlainTextEdit):
         # Apply the selections
         self.setExtraSelections(selections)
 
-    def wheelEvent(self, event):
-        if event.modifiers() & Qt.ControlModifier:
+    def wheelEvent(self, event: QWheelEvent | None) -> None:
+        if event is not None and event.modifiers().value == Qt.Modifier.CTRL.value:
             event.accept()
             self.zoom(1 if event.angleDelta().y()>0 else -1)
         else:
             super(Editor, self).wheelEvent(event)
 
-    def zoom(self, incr):
+    def zoom(self, incr: int) -> None:
         font = self.font()
         point_size = font.pointSize()
         point_size += incr
+        if point_size < 1:
+            return
         font.setPointSize(point_size)
         self.setFont(font)
