@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2024  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2025  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -117,7 +117,7 @@ class relForm(QtWidgets.QMainWindow):
             action.setShortcutContext(QtCore.Qt.ShortcutContext.WidgetShortcut)
             widget.addAction(action)
 
-    def checkVersion(self):
+    def checkVersion(self) -> None:
         from relational import maintenance
         online = maintenance.check_latest_version()
 
@@ -138,7 +138,7 @@ class relForm(QtWidgets.QMainWindow):
         self.ui.lstHistory.setVisible(history_shown)
         self.ui.actionShow_history.setChecked(history_shown)
 
-    def setMultiline(self, multiline):
+    def setMultiline(self, multiline) -> None:
         self.multiline = multiline
         self.settings.setValue('multiline', multiline)
         if multiline:
@@ -151,16 +151,16 @@ class relForm(QtWidgets.QMainWindow):
     def load_query(self, *index):
         self.ui.txtQuery.setText(self.savedQ.itemData(index[0]).toString())
 
-    def undoOptimize(self):
+    def undoOptimize(self) -> None:
         '''Undoes the optimization on the query, popping one item from the undo list'''
         if self.undo != None:
             self.ui.txtQuery.setText(self.undo)
 
-    def undoOptimizeProgram(self):
+    def undoOptimizeProgram(self) -> None:
         if self.undo_program:
             self.ui.txtMultiQuery.setPlainText(self.undo_program)
 
-    def optimizeProgram(self):
+    def optimizeProgram(self) -> None:
         self.undo_program = self.ui.txtMultiQuery.toPlainText()
         result = optimizer.optimize_program(
             self.ui.txtMultiQuery.toPlainText(),
@@ -169,13 +169,13 @@ class relForm(QtWidgets.QMainWindow):
         self.ui.txtMultiQuery.setPlainText(result)
 
 
-    def optimize(self):
+    def optimize(self) -> None:
         '''Performs all the possible optimizations on the query'''
         self.undo = self.ui.txtQuery.text()  # Storing the query in undo list
 
         res_rel,query = self.user_interface.split_query(self.ui.txtQuery.text(),None)
         try:
-            trace = []
+            trace: list[str] = []
             result = optimizer.optimize_all(
                 query,
                 self.user_interface.relations,
@@ -277,13 +277,13 @@ class relForm(QtWidgets.QMainWindow):
         for j in self.user_interface.relations[rel].header:
             self.ui.lstAttributes.addItem(j)
 
-    def updateRelations(self):
+    def updateRelations(self) -> None:
         self.ui.lstRelations.clear()
         for i in self.user_interface.relations:
             if i != "__builtins__":
                 self.ui.lstRelations.addItem(i)
 
-    def saveRelation(self):
+    def saveRelation(self) -> None:
         if not self.ui.lstRelations.selectedItems():
             QtWidgets.QMessageBox.information(
                 self, _('Error'), _('Select a relation first.')
@@ -300,16 +300,16 @@ class relForm(QtWidgets.QMainWindow):
         relname = self.ui.lstRelations.selectedItems()[0].text()
         self.user_interface.store(filename, relname)
 
-    def unloadRelation(self):
+    def unloadRelation(self) -> None:
         for i in self.ui.lstRelations.selectedItems():
             del self.user_interface.relations[i.text()]
         self.updateRelations()
 
-    def newSession(self):
+    def newSession(self) -> None:
         self.user_interface.session_reset()
         self.updateRelations()
 
-    def editRelation(self):
+    def editRelation(self) -> None:
         from relational_gui import creator
         for i in self.ui.lstRelations.selectedItems():
             try:
@@ -325,14 +325,14 @@ class relForm(QtWidgets.QMainWindow):
                 self.user_interface.set_relation(i.text(), result)
         self.updateRelations()
 
-    def error(self, exception):
+    def error(self, exception: Exception) -> None:
         print (exception)
         QtWidgets.QMessageBox.information(
             self, _("Error"),
             str(exception)
         )
 
-    def promptRelationName(self):
+    def promptRelationName(self) -> str | None:
         while True:
             res = QtWidgets.QInputDialog.getText(
                 self,
@@ -364,17 +364,17 @@ class relForm(QtWidgets.QMainWindow):
         except Exception as e:
             self.error(e)
 
-    def closeEvent(self, event):
+    def closeEvent(self, event) -> None:
         self.save_settings()
         event.accept()
 
-    def save_settings(self):
+    def save_settings(self) -> None:
         self.settings.setValue('maingui/geometry', self.saveGeometry())
         self.settings.setValue('maingui/windowState', self.saveState())
         self.settings.setValue('maingui/splitter', self.ui.splitter.saveState())
         self.settings.setValue('maingui/relations', self.user_interface.session_dump())
 
-    def _restore_settings(self):
+    def _restore_settings(self) -> None:
         self.user_interface.session_restore(self.settings.value('maingui/relations'))
         self.updateRelations()
 
@@ -389,7 +389,7 @@ class relForm(QtWidgets.QMainWindow):
         except:
             pass
 
-    def showSurvey(self):
+    def showSurvey(self) -> None:
         if self.Survey is None:
             self.Survey = surveyForm.surveyForm()
             ui = survey.Ui_Form()
@@ -398,7 +398,7 @@ class relForm(QtWidgets.QMainWindow):
             self.Survey.setDefaultValues()
         self.Survey.show()
 
-    def showAbout(self):
+    def showAbout(self) -> None:
         if self.About is None:
             self.About = QtWidgets.QDialog()
             ui = about.Ui_Dialog()
@@ -435,46 +435,46 @@ class relForm(QtWidgets.QMainWindow):
 
         self.updateRelations()
 
-    def addProduct(self):
+    def addProduct(self) -> None:
         self.addSymbolInQuery(parser.PRODUCT)
 
-    def addDifference(self):
+    def addDifference(self) -> None:
         self.addSymbolInQuery(parser.DIFFERENCE)
 
-    def addUnion(self):
+    def addUnion(self) -> None:
         self.addSymbolInQuery(parser.UNION)
 
-    def addIntersection(self):
+    def addIntersection(self) -> None:
         self.addSymbolInQuery(parser.INTERSECTION)
 
-    def addDivision(self):
+    def addDivision(self) -> None:
         self.addSymbolInQuery(parser.DIVISION)
 
-    def addOLeft(self):
+    def addOLeft(self) -> None:
         self.addSymbolInQuery(parser.JOIN_LEFT)
 
-    def addJoin(self):
+    def addJoin(self) -> None:
         self.addSymbolInQuery(parser.JOIN)
 
-    def addORight(self):
+    def addORight(self) -> None:
         self.addSymbolInQuery(parser.JOIN_RIGHT)
 
-    def addOuter(self):
+    def addOuter(self) -> None:
         self.addSymbolInQuery(parser.JOIN_FULL)
 
-    def addProjection(self):
+    def addProjection(self) -> None:
         self.addSymbolInQuery(parser.PROJECTION)
 
-    def addSelection(self):
+    def addSelection(self) -> None:
         self.addSymbolInQuery(parser.SELECTION)
 
-    def addRename(self):
+    def addRename(self) -> None:
         self.addSymbolInQuery(parser.RENAME)
 
-    def addArrow(self):
+    def addArrow(self) -> None:
         self.addSymbolInQuery(parser.ARROW)
 
-    def addSymbolInQuery(self, symbol):
+    def addSymbolInQuery(self, symbol: str)  -> None:
         if self.multiline:
             self.ui.txtMultiQuery.insertPlainText(symbol)
             self.ui.txtMultiQuery.setFocus()
